<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cms_homesite
 */

/**
 * Hook class.
 */
class Hook_endpoint_cms_homesite_user_stats
{
    /**
     * Return information about this endpoint.
     *
     * @param  ?string $type Standard type parameter, usually either of add/edit/delete/view (null: not-set)
     * @param  ?string $id Standard ID parameter (null: not-set)
     * @return ?array Info about the hook (null: endpoint is disabled)
     */
    public function info(?string $type, ?string $id) : ?array
    {
        if (!addon_installed('cms_homesite')) {
            return null;
        }

        return [
            'authorization' => false,
            'log_stats_event' => 'cms_homesite/user_stats',
        ];
    }

    /**
     * Run an API endpoint.
     *
     * @param  ?string $type Standard type parameter, usually either of add/edit/delete/view (null: not-set)
     * @param  ?string $id Standard ID parameter (null: not-set)
     * @return array Data structure that will be converted to correct response type
     */
    public function run(?string $type, ?string $id) : array
    {
        $website_url = substr(get_param_string('url', false, INPUT_FILTER_URL_GENERAL), 0, 255);
        $website_name = substr(get_param_string('name', false, INPUT_FILTER_GET_COMPLEX), 0, 255);
        require_code('version2');
        $version = get_param_string('version');
        $num_members = get_param_integer('num_members');
        $num_hits_per_day = get_param_integer('num_hits_per_day');

        $GLOBALS['SITE_DB']->query_insert('logged', [
            'website_url' => $website_url,
            'website_name' => $website_name,
            'l_version' => $version,
            'hittime' => time(),
            'count_members' => $num_members,
            'num_hits_per_day' => $num_hits_per_day,
        ]);

        if ($id === '_LEGACY_') { // LEGACY
            echo serialize([]);
            exit();
        }

        return [];
    }
}
