<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cms_homesite
 */

/**
 * Hook class.
 */
class Hook_addon_registry_cms_homesite
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the current version of this addon (usually software major, software minor, addon build).
     * Put the comment "// addon_version_auto_update" to the right of the return if you want release tools to automatically update this according to software version and find_addon_effective_mtime.
     *
     * @return SHORT_TEXT Version number
     */
    public function get_version() : string
    {
        return '11.0.1'; // addon_version_auto_update 550d33f8274dffccbb6cc900b5c6547f
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return 11.9;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Development';
    }

    /**
     * Get the addon author.
     *
     * @return string The author
     */
    public function get_author() : string
    {
        return 'Chris Graham';
    }

    /**
     * Find other authors.
     *
     * @return array A list of co-authors that should be attributed
     */
    public function get_copyright_attribution() : array
    {
        return [];
    }

    /**
     * Get the addon licence (one-line summary only).
     *
     * @return string The licence
     */
    public function get_licence() : string
    {
        return 'Licensed on the same terms as ' . brand_name();
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'This addon contains various aspects of the homesite:
 - CMS release management and upgrading
 - homesite addon management scripts
 - CMS download scripts
 - The deployment/hosting platform (Demonstratr)
 - Error message explainer system
 - Various other scripts for running the homesite

This addon does not contain the homesite install code and the overall site and theme. That is not categorised into an addon, but is in the Git branch.
';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [
                //'core_all_icons',
            ],
            'recommends' => [
                'downloads',
                'news',
                'tickets',
                'newsletter',
                'MySQL',
                'cms_homesite_tracker',
                'cms_release_build',
                'composr_tutorials',
                'hybridauth',
                'patreon',
            ],
            'conflicts_with' => [],
            'previously_in_addon' => ['composr_homesite'],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/admin/tool.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'adminzone/pages/minimodules_custom/_make_release.php',
            'adminzone/pages/modules_custom/admin_cmsusers.php',
            'cmscore.rdf',
            'data_custom/download_composr.php',
            'data_custom/keys/.htaccess',
            'data_custom/keys/index.html',
            'data_custom/redirect_release_notes.php',
            'lang_custom/EN/cms_homesite.ini',
            'pages/minimodules_custom/contact.php',
            'pages/minimodules_custom/licence.php',
            'pages/minimodules_custom/report_issue.php',
            'pages/modules_custom/telemetry.php',
            'site/pages/comcode_custom/EN/maintenance_status.txt',
            'site/pages/minimodules_custom/themeing_changes.php',
            'sources_custom/cms_homesite.php',
            'sources_custom/cms_homesite_make_upgrader.php',
            'sources_custom/cns_forumview.php',
            'sources_custom/errorservice.php',
            'sources_custom/hooks/blocks/main_staff_checklist/cms_homesite.php',
            'sources_custom/hooks/endpoints/cms_homesite/.htaccess',
            'sources_custom/hooks/endpoints/cms_homesite/addon_manifest.php',
            'sources_custom/hooks/endpoints/cms_homesite/dummy_data.php',
            'sources_custom/hooks/endpoints/cms_homesite/errorservice.php',
            'sources_custom/hooks/endpoints/cms_homesite/forum_posts.php',
            'sources_custom/hooks/endpoints/cms_homesite/forum_topics.php',
            'sources_custom/hooks/endpoints/cms_homesite/http_status_check.php',
            'sources_custom/hooks/endpoints/cms_homesite/index.html',
            'sources_custom/hooks/endpoints/cms_homesite/newsletter.php',
            'sources_custom/hooks/endpoints/cms_homesite/personal_upgrader.php',
            'sources_custom/hooks/endpoints/cms_homesite/ping.php',
            'sources_custom/hooks/endpoints/cms_homesite/release_details.php',
            'sources_custom/hooks/endpoints/cms_homesite/release_discontinued.php',
            'sources_custom/hooks/endpoints/cms_homesite/telemetry.php',
            'sources_custom/hooks/endpoints/cms_homesite/tracker_categories.php',
            'sources_custom/hooks/endpoints/cms_homesite/tracker_issues.php',
            'sources_custom/hooks/endpoints/cms_homesite/tracker_posts.php',
            'sources_custom/hooks/endpoints/cms_homesite/tracker_sponsorship.php',
            'sources_custom/hooks/endpoints/cms_homesite/user_stats.php',
            'sources_custom/hooks/endpoints/cms_homesite/version.php',
            'sources_custom/hooks/modules/admin_stats/cms_homesite.php',
            'sources_custom/hooks/systems/addon_registry/cms_homesite.php',
            'sources_custom/hooks/systems/health_checks/gitlab.php',
            'sources_custom/hooks/systems/notifications/tracker_issue_added.php',
            'sources_custom/hooks/systems/page_groupings/cms_homesite.php',
            'sources_custom/hooks/systems/points/tracker_issue__report_resolved.php',
            'sources_custom/hooks/systems/points/tracker_issue__resolve.php',
            'sources_custom/hooks/systems/privacy/cms_homesite.php',
            'sources_custom/hooks/systems/resource_meta_aware/tracker_issue.php',
            'sources_custom/hooks/systems/startup/cms_homesite__for_outdated_version.php',
            'sources_custom/hooks/systems/symbols/CMS_REPOS_URL.php',
            'sources_custom/miniblocks/cms_homesite_download.php',
            'sources_custom/miniblocks/cms_homesite_featuretray.php',
            'sources_custom/miniblocks/cms_homesite_make_upgrader.php',
            'sources_custom/miniblocks/cms_maintenance_status.php',
            'sources_custom/miniblocks/main_version_support.php',
            'sources_custom/points_escrow__sponsorship.php',
            'themes/default/images_custom/icons/cms_homesite/index.html',
            'themes/default/images_custom/icons/cms_homesite/theme_upgrade.svg',
            'themes/default/images_custom/icons/cms_homesite/translations_rough.svg',
            'themes/default/images_custom/icons_monochrome/cms_homesite/index.html',
            'themes/default/images_custom/icons_monochrome/cms_homesite/theme_upgrade.svg',
            'themes/default/images_custom/icons_monochrome/cms_homesite/translations_rough.svg',
            'themes/default/templates_custom/BLOCK_CMS_MAINTENANCE_STATUS.tpl',
            'themes/default/templates_custom/CMS_BLOCK_MAIN_VERSION_SUPPORT.tpl',
            'themes/default/templates_custom/CMS_DOWNLOAD_BLOCK.tpl',
            'themes/default/templates_custom/CMS_DOWNLOAD_RELEASES.tpl',
            'uploads/website_specific/cms_homesite/.htaccess',
            'uploads/website_specific/cms_homesite/banners.zip',
            'uploads/website_specific/cms_homesite/errorservice.csv',
            'uploads/website_specific/cms_homesite/facebook.html',
            'uploads/website_specific/cms_homesite/index.html',
            'uploads/website_specific/cms_homesite/logos/a.png',
            'uploads/website_specific/cms_homesite/logos/b.png',
            'uploads/website_specific/cms_homesite/logos/choice.php',
            'uploads/website_specific/cms_homesite/logos/default.png',
            'uploads/website_specific/cms_homesite/logos/index.html',
            'uploads/website_specific/cms_homesite/upgrades/index.html',
            'uploads/website_specific/cms_homesite/upgrades/sample_data/index.html',
            'uploads/website_specific/cms_homesite/upgrades/tar_build/index.html',
            'uploads/website_specific/cms_homesite/upgrades/tars/index.html',
        ];
    }
}
